package com.ruoyi.system.service;

import com.baomidou.mybatisplus.extension.service.IService;
import com.ruoyi.system.domain.OperatingHours;

import java.util.List;

/**
 * OperatingHoursService接口
 * 
 * @author ruoyi
 * @date 2025-02-11
 */
public interface IOperatingHoursService extends IService<OperatingHours>
{
    /**
     * 查询OperatingHours
     * 
     * @param id OperatingHours主键
     * @return OperatingHours
     */
    public OperatingHours selectOperatingHoursById(Long id);

    /**
     * 查询OperatingHours列表
     * 
     * @param operatingHours OperatingHours
     * @return OperatingHours集合
     */
    public List<OperatingHours> selectOperatingHoursList(OperatingHours operatingHours);

    /**
     * 新增OperatingHours
     * 
     * @param operatingHours OperatingHours
     * @return 结果
     */
    public int insertOperatingHours(OperatingHours operatingHours);

    /**
     * 修改OperatingHours
     * 
     * @param operatingHours OperatingHours
     * @return 结果
     */
    public int updateOperatingHours(OperatingHours operatingHours);

    /**
     * 批量删除OperatingHours
     * 
     * @param ids 需要删除的OperatingHours主键集合
     * @return 结果
     */
    public int deleteOperatingHoursByIds(Long[] ids);

    /**
     * 删除OperatingHours信息
     * 
     * @param id OperatingHours主键
     * @return 结果
     */
    public int deleteOperatingHoursById(Long id);

    /**
     * 新增OperatingHours并返回主键
     * @param operatingHours
     * @return
     */
    public Long insertOperatingHoursReturnId(OperatingHours operatingHours);
}
